// The Chilkat v9.5.0.93 API for the Go programming language.
package chilkat

/*
#include <stdlib.h>
#cgo CPPFLAGS: -DCK_GO_LANG
#include "c_includes/C_CkPkcs11.h"


typedef unsigned char UBYTE;
#include "c_includes/C_CkByteData.h"


// Set CGO_LDFLAGS environment variable for linker options.
// for example (on Windows):  -LC:/ckBuildSystems/go/chilkatLib/tdm-5.1.0-64 -lchilkatExt-9.5.0 -lws2_32 -lstdc++

*/
import "C"
import "unsafe"

func NewPkcs11() *Pkcs11 {
	return &Pkcs11{C.CkPkcs11_Create()}
}

func (z *Pkcs11) DisposePkcs11() {
    if z != nil {
	C.CkPkcs11_Dispose(z.ckObj)
	}
}




// property: DebugLogFilePath
// If set to a file path, causes each Chilkat method or property call to
// automatically append it's LastErrorText to the specified log file. The
// information is appended such that if a hang or crash occurs, it is possible to
// see the context in which the problem occurred, as well as a history of all
// Chilkat calls up to the point of the problem. The VerboseLogging property can be
// set to provide more detailed information. 
// 
// This property is typically used for debugging the rare cases where a Chilkat
// method call hangs or generates an exception that halts program execution (i.e.
// crashes). A hang or crash should generally never happen. The typical causes of a
// hang are: 
//     a timeout related property was set to 0 to explicitly indicate that an
//     infinite timeout is desired, 
//     the hang is actually a hang within an event callback (i.e. it is a hang
//     within the application code), or 
//     there is an internal problem (bug) in the Chilkat code that causes the hang.
//     
//
func (z *Pkcs11) DebugLogFilePath() string {
    return C.GoString(C.CkPkcs11_debugLogFilePath(z.ckObj))
}
// property setter: DebugLogFilePath
func (z *Pkcs11) SetDebugLogFilePath(goStr string) {
    cStr := C.CString(goStr)
    C.CkPkcs11_putDebugLogFilePath(z.ckObj,cStr)
    C.free(unsafe.Pointer(cStr))
}

// property: LastErrorHtml
// Provides information in HTML format about the last method/property called. If a
// method call returns a value indicating failure, or behaves unexpectedly, examine
// this property to get more information.
func (z *Pkcs11) LastErrorHtml() string {
    return C.GoString(C.CkPkcs11_lastErrorHtml(z.ckObj))
}

// property: LastErrorText
// Provides information in plain-text format about the last method/property called.
// If a method call returns a value indicating failure, or behaves unexpectedly,
// examine this property to get more information.
func (z *Pkcs11) LastErrorText() string {
    return C.GoString(C.CkPkcs11_lastErrorText(z.ckObj))
}

// property: LastErrorXml
// Provides information in XML format about the last method/property called. If a
// method call returns a value indicating failure, or behaves unexpectedly, examine
// this property to get more information.
func (z *Pkcs11) LastErrorXml() string {
    return C.GoString(C.CkPkcs11_lastErrorXml(z.ckObj))
}

// property: LastMethodSuccess
// Indicate whether the last method call succeeded or failed. A value of true
// indicates success, a value of false indicates failure. This property is
// automatically set for method calls. It is not modified by property accesses. The
// property is automatically set to indicate success for the following types of
// method calls: 
//     Any method that returns a string. 
//     Any method returning a Chilkat object, binary bytes, or a date/time. 
//     Any method returning a standard boolean status value where success = true
//     and failure = false. 
//     Any method returning an integer where failure is defined by a return value
//     less than zero. 
// 
// Note: Methods that do not fit the above requirements will always set this
// property equal to true. For example, a method that returns no value (such as a
// "void" in C++) will technically always succeed.
//
func (z *Pkcs11) LastMethodSuccess() bool {
    v := int(C.CkPkcs11_getLastMethodSuccess(z.ckObj))
    return v != 0
}
// property setter: LastMethodSuccess
func (z *Pkcs11) SetLastMethodSuccess(value bool) {
    v := C.int(0)
    if value {
            v = C.int(1)
    }
    C.CkPkcs11_putLastMethodSuccess(z.ckObj,v)
}

// property: NumCerts
// The number of certificates contained on the smart card or USB token. This
// property is set when FindAllCerts is called.
func (z *Pkcs11) NumCerts() int {
    return int(C.CkPkcs11_getNumCerts(z.ckObj))
}

// property: SharedLibPath
// On Windows systems, then should be set to the name of the DLL file (if the DLL
// is located in C:\Windows\System32), or it can be the full path to the DLL. 
// 
// On Linux, MacOSX, or other non-Windows systems, this can also be either the full
// path to the .so or .dylib, or just the .so or .dylib filename. On these systems,
// Chilkat calls the dlopen system function
// <https://man7.org/linux/man-pages/man3/dlopen.3.html> to load the shared
// library. If just the filename is passed in, the directories searched are those
// indicated in the dlopen function description at
// https://man7.org/linux/man-pages/man3/dlopen.3.html
//
func (z *Pkcs11) SharedLibPath() string {
    return C.GoString(C.CkPkcs11_sharedLibPath(z.ckObj))
}
// property setter: SharedLibPath
func (z *Pkcs11) SetSharedLibPath(goStr string) {
    cStr := C.CString(goStr)
    C.CkPkcs11_putSharedLibPath(z.ckObj,cStr)
    C.free(unsafe.Pointer(cStr))
}

// property: VerboseLogging
// If set to true, then the contents of LastErrorText (or LastErrorXml, or
// LastErrorHtml) may contain more verbose information. The default value is
// false. Verbose logging should only be used for debugging. The potentially
// large quantity of logged information may adversely affect peformance.
func (z *Pkcs11) VerboseLogging() bool {
    v := int(C.CkPkcs11_getVerboseLogging(z.ckObj))
    return v != 0
}
// property setter: VerboseLogging
func (z *Pkcs11) SetVerboseLogging(value bool) {
    v := C.int(0)
    if value {
            v = C.int(1)
    }
    C.CkPkcs11_putVerboseLogging(z.ckObj,v)
}

// property: Version
// Version of the component/library, such as "9.5.0.63"
func (z *Pkcs11) Version() string {
    return C.GoString(C.CkPkcs11_version(z.ckObj))
}
// Closes the session on the token (i.e. smart card). 
// 
// Note: Memory leaks can occur if the session is not properly closed.
//
func (z *Pkcs11) CloseSession() bool {

    v := C.CkPkcs11_CloseSession(z.ckObj)


    return v != 0
}


// Discovers the readers, smart cards, and USB tokens accessible via PKCS11 on the
// computer (using the DLL/shared lib specified by SharedLibPath). The onlyTokensPresent
// specifies if only slots (readers) with tokens (smart cards) present should be
// returned. The information is written to the json. (For details, see the example
// below.)
func (z *Pkcs11) Discover(arg1 bool, arg2 *JsonObject) bool {
    b1 := C.int(0)
    if arg1 {
        b1 = C.int(1)
    }

    v := C.CkPkcs11_Discover(z.ckObj, b1, arg2.ckObj)


    return v != 0
}


// Finds all certificates contained on the smart card (or USB token). This sets the
// NumCerts property. Each certificate can be obtained by calling GetCert(index)
// where the 1st cert is at index 0. 
// 
// Important: Private keys will not be seen unless the PKCS11 session is
// authenticated. To authenticate, your application must call Login after calling
// OpenSession.
//
func (z *Pkcs11) FindAllCerts() bool {

    v := C.CkPkcs11_FindAllCerts(z.ckObj)


    return v != 0
}


// Finds the certificate where the given certPart equals the partValue. Possible values for
// certPart are: "privateKey", "subjectDN", "subjectDN_withTags", "subjectCN",
// "serial", or "serial:issuerCN". If certPart equals "privateKey", then pass an empty
// string in partValue. Specifying "privateKey" means to return the first certificate
// having a private key. 
// 
// The cert is loaded with the certificate if successful. 
// 
// Important: Private keys will not be seen unless the PKCS11 session is
// authenticated. To authenticate, your application must call Login after calling
// OpenSession.
// 
// Note: If successful, the cert will be linked internally with this PKCS11 session
// such that certificate can be used for signing on the smart card when used in
// other Chilkat classes such as XmlDSigGen, Pdf, Crypt2, Mime, MailMan, etc.
//
func (z *Pkcs11) FindCert(arg1 string, arg2 string, arg3 *Cert) bool {
    cstr1 := C.CString(arg1)
    cstr2 := C.CString(arg2)

    v := C.CkPkcs11_FindCert(z.ckObj, cstr1, cstr2, arg3.ckObj)

    C.free(unsafe.Pointer(cstr1))
    C.free(unsafe.Pointer(cstr2))

    return v != 0
}


// Loads cert with the Nth certificate indicated by index. The 1st certificate is at
// index 0. The FindAllCerts method must be called beforehand to load the certs
// from the smart card into this object. After calling FindAllCerts, the NumCerts
// property is set and each certificate can be retrieved by calling GetCert.
func (z *Pkcs11) GetCert(arg1 int, arg2 *Cert) bool {

    v := C.CkPkcs11_GetCert(z.ckObj, C.int(arg1), arg2.ckObj)


    return v != 0
}


// Initializes the PKCS#11 library. Should be called after specifying the
// SharedLibPath. The DLL (or .so/.dylib) is dynamically loaded and the PKCS#11 lib
// is initialized.
func (z *Pkcs11) Initialize() bool {

    v := C.CkPkcs11_Initialize(z.ckObj)


    return v != 0
}


// Initializes the normal user's PIN. This must be called from the security
// officer's (SO) logged-in session. 
// 
// Note: To unblock a smart card, login to the SO (Security Officer) session using
// the PUK, and then call this with the new user PIN.
//
func (z *Pkcs11) InitPin(arg1 string) bool {
    cstr1 := C.CString(arg1)

    v := C.CkPkcs11_InitPin(z.ckObj, cstr1)

    C.free(unsafe.Pointer(cstr1))

    return v != 0
}


// Initializes a token. slotId is the slot ID of the token's slot. 
// 
// If the token has not been initialized (i.e. new from the factory), then the pPin
// parameter becomes the initial value of the SO (Security Officer) PIN. If the
// token is being reinitialized, the pin parameter is checked against the existing
// SO PIN to authorize the initialization operation. 
// 
// When a token is initialized, all objects that can be destroyed are destroyed
// (i.e., all except for “indestructible” objects such as keys built into the
// token). Also, access by the normal user is disabled until the SO sets the normal
// user’s PIN. Depending on the token, some “default” objects may be created, and
// attributes of some objects may be set to default values.
//
func (z *Pkcs11) InitToken(arg1 int, arg2 string, arg3 string) bool {
    cstr2 := C.CString(arg2)
    cstr3 := C.CString(arg3)

    v := C.CkPkcs11_InitToken(z.ckObj, C.int(arg1), cstr2, cstr3)

    C.free(unsafe.Pointer(cstr2))
    C.free(unsafe.Pointer(cstr3))

    return v != 0
}


// Authenticates a session with a PIN. The userType can be one of the following integer
// values: 
//     Security Officer (0)
//     Normal User (1)
//     Context Specific (2)
// 
// Except for special circumstances, you'll always login as the Normal User.
//
func (z *Pkcs11) Login(arg1 int, arg2 string) bool {
    cstr2 := C.CString(arg2)

    v := C.CkPkcs11_Login(z.ckObj, C.int(arg1), cstr2)

    C.free(unsafe.Pointer(cstr2))

    return v != 0
}


// Logs out from a token (smart card).
func (z *Pkcs11) Logout() bool {

    v := C.CkPkcs11_Logout(z.ckObj)


    return v != 0
}


// Opens a session on the token (i.e. smart card). The slotId is the ID of the slot
// (not the index). Set slotId equal to -1 to choose the first available non-empty
// slot. The readWrite indicates whether the session should be read-only or read-write. 
// 
// The PKCS11 terminology is confusing:
// 
//     A "slot" corresponds to a connected smart card reader or USB hardware token,
//     such as a Feitian ePass3003Auto token.
//     A "token" corresponds to the smart card inserted into the reader. If we have
//     a USB hardware token, such as the epass3003Auto (or many others), then
//     technically there is always a "smart card" inserted, because the USB hardware
//     token is effectively both the reader and smart card wrapped in one inseparable
//     device.
//     The PKCS11 DLL (or .so shared lib, or .dylib) is the vendor supplied PKCS11
//     implementation (driver) that provides the low-level "C" PKCS11 functions (called
//     by Chilkat internally).
//     Generally, the number of slots will equal the number of connected smart
//     cards or tokens belonging to the vendor of the DLL, or compatible with the DLL.
//     In most cases you'll have your single reader with a single smart card inserted,
//     and therefore only one slot exists.
//     Some PKCS11 DLLs are provided by a 3rd party and support many smart cards.
//     For example, A.E.T. Europe B.V.'s "SafeSign Identity Client Standard Version
//     3.5" DLL is "aetpkss1.dll". It supports the following tokens:
//         Defensiepas
//         Defensiepas 2
//         G&D Convego Join 4.01 40k/80k
//         G&D SkySIM Hercules
//         G&D SkySIM Scorpius
//         G&D Sm@rtCafé Expert 3.2
//         G&D Sm@rtCafé Expert 4.0
//         G&D Sm@rtCafé Expert 5.0
//         G&D Sm@rtCafé Expert 6.0
//         G&D Sm@rtCafé Expert 7.0
//         G&D Sm@rtCafé Expert 64
//         Gemalto Desineo ICP D72 FXR1 Java
//         Gemalto IDCore 30
//         Gemalto MultiApp ID v2.1
//         Gemalto Optelio D72 FR1
//         Gemalto TOP DL v2
//         Infineon Oracle JCOS Ed.1
//         JCOP21 v2.3
//         Morpho IDealCitiz v2.1
//         Morpho JMV ProCL V3.0
//         NXP J2A080 / J2A081 (JCOP 2.4.1 R3)
//         NXP JD081 (JCOP 2.4.1 R3)
//         NXP J3A080 (JCOP 2.4.1 R3)
//         NXP JCOP 2.4.2 R3
//         NXP JCOP 3 SecID P60
//         Oberthur IDOne Cosmo v7.0
//         RDW ABR kaart
//         Rijkspas
//         Rijkspas 2
//         Sagem YpsID s2
//         Sagem YpsID s3
//         StarSign Crypto USB Token S
//         Swissbit PS-100u SE
//         UZI-pas
//         UZI-pas 2
func (z *Pkcs11) OpenSession(arg1 int, arg2 bool) bool {
    b2 := C.int(0)
    if arg2 {
        b2 = C.int(1)
    }

    v := C.CkPkcs11_OpenSession(z.ckObj, C.int(arg1), b2)


    return v != 0
}


// Modifies the PIN of the user that is currently logged in, or the Normal User PIN
// if the session is not logged in.
func (z *Pkcs11) SetPin(arg1 string, arg2 string) bool {
    cstr1 := C.CString(arg1)
    cstr2 := C.CString(arg2)

    v := C.CkPkcs11_SetPin(z.ckObj, cstr1, cstr2)

    C.free(unsafe.Pointer(cstr1))
    C.free(unsafe.Pointer(cstr2))

    return v != 0
}


