// The Chilkat v9.5.0.93 API for the Go programming language.
package chilkat

/*
#include <stdlib.h>
#cgo CPPFLAGS: -DCK_GO_LANG
#include "c_includes/C_CkSCard.h"


typedef unsigned char UBYTE;
#include "c_includes/C_CkByteData.h"


// Set CGO_LDFLAGS environment variable for linker options.
// for example (on Windows):  -LC:/ckBuildSystems/go/chilkatLib/tdm-5.1.0-64 -lchilkatExt-9.5.0 -lws2_32 -lstdc++

*/
import "C"
import "unsafe"

func NewSCard() *SCard {
	return &SCard{C.CkSCard_Create(),ChilkatCallbacks{nil,nil,nil,nil}}
}

func (z *SCard) DisposeSCard() {
    if z != nil {
	C.CkSCard_Dispose(z.ckObj)
	}
}




func (z *SCard) SetCallbackUserData(userData interface{}) {
    z.callbacks.UserData = userData;
    C.CkSCard_setCallbackContext(z.ckObj,unsafe.Pointer(&z.callbacks))
}

func (z *SCard) SetProgressInfo(f ChilkatProgressInfo) {
    z.callbacks.ProgressInfo = f
    C.CkSCard_setExternalProgress(z.ckObj,1)
}

func (z *SCard) SetAbortCheck(f ChilkatAbortCheck) {
    z.callbacks.AbortCheck = f
    C.CkSCard_setExternalProgress(z.ckObj,1)
}

func (z *SCard) SetPercentDone(f ChilkatPercentDone) {
    z.callbacks.PercentDone = f
    C.CkSCard_setExternalProgress(z.ckObj,1)
}




// property: ActiveProtocol
// The name of the active protocol if connected smart card reader, or an empty
// string if not connected. Possible values are "T0", "T1", "raw", "undefined", or
// "" if not connected to a reader.
func (z *SCard) ActiveProtocol() string {
    return C.GoString(C.CkSCard_activeProtocol(z.ckObj))
}

// property: CardAtr
// This is the Current ATR of a card in the connected reader.
func (z *SCard) CardAtr() string {
    return C.GoString(C.CkSCard_cardAtr(z.ckObj))
}

// property: ConnectedReader
// The name of the currently connected smart card reader, or an empty string if not
// connected.
func (z *SCard) ConnectedReader() string {
    return C.GoString(C.CkSCard_connectedReader(z.ckObj))
}

// property: Context
// Contains the string "user" or "system" if this object has established a context
// (by calling EstablishContext). Contains the empty string if no context is
// established.
func (z *SCard) Context() string {
    return C.GoString(C.CkSCard_context(z.ckObj))
}

// property: DebugLogFilePath
// If set to a file path, causes each Chilkat method or property call to
// automatically append it's LastErrorText to the specified log file. The
// information is appended such that if a hang or crash occurs, it is possible to
// see the context in which the problem occurred, as well as a history of all
// Chilkat calls up to the point of the problem. The VerboseLogging property can be
// set to provide more detailed information. 
// 
// This property is typically used for debugging the rare cases where a Chilkat
// method call hangs or generates an exception that halts program execution (i.e.
// crashes). A hang or crash should generally never happen. The typical causes of a
// hang are: 
//     a timeout related property was set to 0 to explicitly indicate that an
//     infinite timeout is desired, 
//     the hang is actually a hang within an event callback (i.e. it is a hang
//     within the application code), or 
//     there is an internal problem (bug) in the Chilkat code that causes the hang.
//     
//
func (z *SCard) DebugLogFilePath() string {
    return C.GoString(C.CkSCard_debugLogFilePath(z.ckObj))
}
// property setter: DebugLogFilePath
func (z *SCard) SetDebugLogFilePath(goStr string) {
    cStr := C.CString(goStr)
    C.CkSCard_putDebugLogFilePath(z.ckObj,cStr)
    C.free(unsafe.Pointer(cStr))
}

// property: LastErrorHtml
// Provides information in HTML format about the last method/property called. If a
// method call returns a value indicating failure, or behaves unexpectedly, examine
// this property to get more information.
func (z *SCard) LastErrorHtml() string {
    return C.GoString(C.CkSCard_lastErrorHtml(z.ckObj))
}

// property: LastErrorText
// Provides information in plain-text format about the last method/property called.
// If a method call returns a value indicating failure, or behaves unexpectedly,
// examine this property to get more information.
func (z *SCard) LastErrorText() string {
    return C.GoString(C.CkSCard_lastErrorText(z.ckObj))
}

// property: LastErrorXml
// Provides information in XML format about the last method/property called. If a
// method call returns a value indicating failure, or behaves unexpectedly, examine
// this property to get more information.
func (z *SCard) LastErrorXml() string {
    return C.GoString(C.CkSCard_lastErrorXml(z.ckObj))
}

// property: LastMethodSuccess
// Indicate whether the last method call succeeded or failed. A value of true
// indicates success, a value of false indicates failure. This property is
// automatically set for method calls. It is not modified by property accesses. The
// property is automatically set to indicate success for the following types of
// method calls: 
//     Any method that returns a string. 
//     Any method returning a Chilkat object, binary bytes, or a date/time. 
//     Any method returning a standard boolean status value where success = true
//     and failure = false. 
//     Any method returning an integer where failure is defined by a return value
//     less than zero. 
// 
// Note: Methods that do not fit the above requirements will always set this
// property equal to true. For example, a method that returns no value (such as a
// "void" in C++) will technically always succeed.
//
func (z *SCard) LastMethodSuccess() bool {
    v := int(C.CkSCard_getLastMethodSuccess(z.ckObj))
    return v != 0
}
// property setter: LastMethodSuccess
func (z *SCard) SetLastMethodSuccess(value bool) {
    v := C.int(0)
    if value {
            v = C.int(1)
    }
    C.CkSCard_putLastMethodSuccess(z.ckObj,v)
}

// property: PcscLibPath
// For Linux systems only. Specifies the full path of the libpcsclite.so shared
// lib. This property should only be used if the libpcsclite.so is in a
// non-standard location or if Chilkat cannot automatically located it.
func (z *SCard) PcscLibPath() string {
    return C.GoString(C.CkSCard_pcscLibPath(z.ckObj))
}
// property setter: PcscLibPath
func (z *SCard) SetPcscLibPath(goStr string) {
    cStr := C.CString(goStr)
    C.CkSCard_putPcscLibPath(z.ckObj,cStr)
    C.free(unsafe.Pointer(cStr))
}

// property: ReaderStatus
// The current status of the connected reader. Possible values are: 
//     "absent" - There is no card in the reader.
//     "present" - There is a card in the reader, but it has not been moved into
//     position for use.
//     "swallowed" - There is a card in the reader in position for use. The card is
//     not powered.
//     "powered" - Power is being provided to the card, but the reader driver is
//     unaware of the mode of the card.
//     "negotiable" - The card has been reset and is awaiting PTS negotiation.
//     "specific" - The card has been reset and specific communication protocols
//     have been established.
func (z *SCard) ReaderStatus() string {
    return C.GoString(C.CkSCard_readerStatus(z.ckObj))
}

// property: ScardError
// The last error returned by an underlying PC/SC function. Can be one of the
// following: 
//     "SCARD_W_REMOVED_CARD" - The smart card has been removed, so that further
//     communication is not possible.
//     "SCARD_W_RESET_CARD" - The smart card has been reset, so any shared state
//     information is invalid.
// ...
func (z *SCard) ScardError() string {
    return C.GoString(C.CkSCard_scardError(z.ckObj))
}

// property: VerboseLogging
// If set to true, then the contents of LastErrorText (or LastErrorXml, or
// LastErrorHtml) may contain more verbose information. The default value is
// false. Verbose logging should only be used for debugging. The potentially
// large quantity of logged information may adversely affect peformance.
func (z *SCard) VerboseLogging() bool {
    v := int(C.CkSCard_getVerboseLogging(z.ckObj))
    return v != 0
}
// property setter: VerboseLogging
func (z *SCard) SetVerboseLogging(value bool) {
    v := C.int(0)
    if value {
            v = C.int(1)
    }
    C.CkSCard_putVerboseLogging(z.ckObj,v)
}

// property: Version
// Version of the component/library, such as "9.5.0.63"
func (z *SCard) Version() string {
    return C.GoString(C.CkSCard_version(z.ckObj))
}
// Establishes a temporary exclusive access mode for doing a series of commands in
// a transaction.
func (z *SCard) BeginTransaction() bool {

    v := C.CkSCard_BeginTransaction(z.ckObj)


    return v != 0
}


// Check the current status of the currently connected reader. Calling this method
// updates the ReaderStatus, ActiveProtocol, and CardAtr properties. If this method
// returns false, none of the properties are updated.
func (z *SCard) CheckStatus() bool {

    v := C.CkSCard_CheckStatus(z.ckObj)


    return v != 0
}


// Establish a connection to a reader. The reader is the name of a reader returned
// from ListReaders. The shareMode can be "shared", "exclusive", or "direct". The preferredProtocol
// can be "0" (valid only if the shareMode = "direct"), "T0", "T1", "raw", or
// "no_preference". (No preference is effectively T0 or T1.) 
// 
// If successful, the state of this object instance is that it's connected to the
// reader.
//
func (z *SCard) Connect(arg1 string, arg2 string, arg3 string) bool {
    cstr1 := C.CString(arg1)
    cstr2 := C.CString(arg2)
    cstr3 := C.CString(arg3)

    v := C.CkSCard_Connect(z.ckObj, cstr1, cstr2, cstr3)

    C.free(unsafe.Pointer(cstr1))
    C.free(unsafe.Pointer(cstr2))
    C.free(unsafe.Pointer(cstr3))

    return v != 0
}


// Terminates a connection with a reader. The disposition can be one of the following
// values: 
//     "leave": Do nothing.
//     "reset": Reset the card (warm reset).
//     "unpower": Power down the card (cold reset).
//     "eject": Eject the card.
func (z *SCard) Disconnect(arg1 string) bool {
    cstr1 := C.CString(arg1)

    v := C.CkSCard_Disconnect(z.ckObj, cstr1)

    C.free(unsafe.Pointer(cstr1))

    return v != 0
}


// Ends a previously begun transaction. The disposition is the action to be taken on the
// reader, and can be "leave" which is to do nothing, "reset", "unpower", or
// "eject".
func (z *SCard) EndTransaction(arg1 string) bool {
    cstr1 := C.CString(arg1)

    v := C.CkSCard_EndTransaction(z.ckObj, cstr1)

    C.free(unsafe.Pointer(cstr1))

    return v != 0
}


// Creates an Application Context to the PC/SC Resource Manager. This must be the
// first WinSCard function called in a PC/SC application. The scope can be "user" or
// "system". After calling, this object will have context and all other methods
// will use the established context. The "Context" property will hold the value
// "user" or "system" if context was established, or will be empty if no context
// was established.
func (z *SCard) EstablishContext(arg1 string) bool {
    cstr1 := C.CString(arg1)

    v := C.CkSCard_EstablishContext(z.ckObj, cstr1)

    C.free(unsafe.Pointer(cstr1))

    return v != 0
}


// Returns JSON containing information about the smartcards currently inserted into
// readers.
func (z *SCard) FindSmartcards(arg1 *JsonObject) bool {

    v := C.CkSCard_FindSmartcards(z.ckObj, arg1.ckObj)


    return v != 0
}


// Get an attribute from the IFD Handler (reader driver). 
// 
// The attr can be one of the following: 
//     "ASYNC_PROTOCOL_TYPES"
//     "ATR_STRING"
//     "CHANNEL_ID"
//     "CHARACTERISTICS"
//     "CURRENT_BWT"
//     "CURRENT_CLK"
//     "CURRENT_CWT"
//     "CURRENT_D"
//     "CURRENT_EBC_ENCODING"
//     "CURRENT_F"
//     "CURRENT_IFSC"
//     "CURRENT_IFSD"
//     "CURRENT_IO_STATE"
//     "CURRENT_N"
//     "CURRENT_PROTOCOL_TYPE"
//     "CURRENT_W"
//     "DEFAULT_CLK"
//     "DEFAULT_DATA_RATE"
//     "DEVICE_FRIENDLY_NAME"
//     "DEVICE_IN_USE"
//     "DEVICE_SYSTEM_NAME"
//     "DEVICE_UNIT"
//     "ESC_AUTHREQUEST"
//     "ESC_CANCEL"
//     "ESC_RESET"
//     "EXTENDED_BWT"
//     "ICC_INTERFACE_STATUS"
//     "ICC_PRESENCE"
//     "ICC_TYPE_PER_ATR"
//     "MAX_CLK"
//     "MAX_DATA_RATE"
//     "MAX_IFSD"
//     "MAXINPUT"
//     "POWER_MGMT_SUPPORT"
//     "SUPRESS_T1_IFS_REQUEST"
//     "SYNC_PROTOCOL_TYPES"
//     "USER_AUTH_INPUT_DEVICE"
//     "USER_TO_CARD_AUTH_DEVICE"
//     "VENDOR_IFD_SERIAL_NO"
//     "VENDOR_IFD_TYPE"
//     "VENDOR_IFD_VERSION"
//     "VENDOR_NAME"
// 
// The attribute data is returned in bd.
//
func (z *SCard) GetAttrib(arg1 string, arg2 *BinData) bool {
    cstr1 := C.CString(arg1)

    v := C.CkSCard_GetAttrib(z.ckObj, cstr1, arg2.ckObj)

    C.free(unsafe.Pointer(cstr1))

    return v != 0
}


// Get a string typed attribute from the IFD Handler (reader driver). 
// 
// The attr can be one of the following, but should be limited to the particular
// attributes that return string values. 
//     "ASYNC_PROTOCOL_TYPES"
//     "ATR_STRING"
//     "CHANNEL_ID"
//     "CHARACTERISTICS"
//     "CURRENT_BWT"
//     "CURRENT_CLK"
//     "CURRENT_CWT"
//     "CURRENT_D"
//     "CURRENT_EBC_ENCODING"
//     "CURRENT_F"
//     "CURRENT_IFSC"
//     "CURRENT_IFSD"
//     "CURRENT_IO_STATE"
//     "CURRENT_N"
//     "CURRENT_PROTOCOL_TYPE"
//     "CURRENT_W"
//     "DEFAULT_CLK"
//     "DEFAULT_DATA_RATE"
//     "DEVICE_FRIENDLY_NAME"
//     "DEVICE_IN_USE"
//     "DEVICE_SYSTEM_NAME"
//     "DEVICE_UNIT"
//     "ESC_AUTHREQUEST"
//     "ESC_CANCEL"
//     "ESC_RESET"
//     "EXTENDED_BWT"
//     "ICC_INTERFACE_STATUS"
//     "ICC_PRESENCE"
//     "ICC_TYPE_PER_ATR"
//     "MAX_CLK"
//     "MAX_DATA_RATE"
//     "MAX_IFSD"
//     "MAXINPUT"
//     "POWER_MGMT_SUPPORT"
//     "SUPRESS_T1_IFS_REQUEST"
//     "SYNC_PROTOCOL_TYPES"
//     "USER_AUTH_INPUT_DEVICE"
//     "USER_TO_CARD_AUTH_DEVICE"
//     "VENDOR_IFD_SERIAL_NO"
//     "VENDOR_IFD_TYPE"
//     "VENDOR_IFD_VERSION"
//     "VENDOR_NAME"
//
// return a string or nil if failed.
func (z *SCard) GetAttribStr(arg1 string) *string {
    cstr1 := C.CString(arg1)

    retStr := C.CkSCard_getAttribStr(z.ckObj, cstr1)

    C.free(unsafe.Pointer(cstr1))

        if retStr == nil {
            return nil
            }
        retGoStr := C.GoString(retStr)
        return &retGoStr
}


// Get an unsigned integer typed attribute from the IFD Handler (reader driver). 
// 
// The attr can be one of the following, but should be limited to the particular
// attributes that return unsigned integer values. 
//     "ASYNC_PROTOCOL_TYPES"
//     "ATR_STRING"
//     "CHANNEL_ID"
//     "CHARACTERISTICS"
//     "CURRENT_BWT"
//     "CURRENT_CLK"
//     "CURRENT_CWT"
//     "CURRENT_D"
//     "CURRENT_EBC_ENCODING"
//     "CURRENT_F"
//     "CURRENT_IFSC"
//     "CURRENT_IFSD"
//     "CURRENT_IO_STATE"
//     "CURRENT_N"
//     "CURRENT_PROTOCOL_TYPE"
//     "CURRENT_W"
//     "DEFAULT_CLK"
//     "DEFAULT_DATA_RATE"
//     "DEVICE_FRIENDLY_NAME"
//     "DEVICE_IN_USE"
//     "DEVICE_SYSTEM_NAME"
//     "DEVICE_UNIT"
//     "ESC_AUTHREQUEST"
//     "ESC_CANCEL"
//     "ESC_RESET"
//     "EXTENDED_BWT"
//     "ICC_INTERFACE_STATUS"
//     "ICC_PRESENCE"
//     "ICC_TYPE_PER_ATR"
//     "MAX_CLK"
//     "MAX_DATA_RATE"
//     "MAX_IFSD"
//     "MAXINPUT"
//     "POWER_MGMT_SUPPORT"
//     "SUPRESS_T1_IFS_REQUEST"
//     "SYNC_PROTOCOL_TYPES"
//     "USER_AUTH_INPUT_DEVICE"
//     "USER_TO_CARD_AUTH_DEVICE"
//     "VENDOR_IFD_SERIAL_NO"
//     "VENDOR_IFD_TYPE"
//     "VENDOR_IFD_VERSION"
//     "VENDOR_NAME"
// 
// Returns 0xFFFFFFFF on failure.
//
func (z *SCard) GetAttribUint(arg1 string) uint {
    cstr1 := C.CString(arg1)

    v := C.CkSCard_GetAttribUint(z.ckObj, cstr1)

    C.free(unsafe.Pointer(cstr1))

    return uint(v)
}


// Blocks execution until the current availability of the cards in a specific set
// of readers changes. 
// 
// This function receives a list of reader names in stReaderNames. It then blocks waiting
// for a change in state to occur for a maximum blocking time of maxWaitMs (in
// milliseconds) or forever if 0 is used. 
// 
// Information about the current reader states and which reader(s) changed is
// returned in json. See the example below for more information. 
// 
// To wait for a reader event (reader added or removed) you may use the special
// reader name "\\?PnP?\Notification". 
// 
// To cancel the ongoing call, call Cancel(). 
// 
// The stReaderNames contains the reader names to check. The json is empty on input, and if
// the call returns success contains information about the state (after the event
// change) of each reader.
//
func (z *SCard) GetStatusChange(arg1 int, arg2 *StringTable, arg3 *JsonObject) bool {

    v := C.CkSCard_GetStatusChange(z.ckObj, C.int(arg1), arg2.ckObj, arg3.ckObj)


    return v != 0
}


// Asynchronous version of the GetStatusChange method
func (z *SCard) GetStatusChangeAsync(arg1 int, arg2 *StringTable, arg3 *JsonObject, c chan *Task) {

    hTask := C.CkSCard_GetStatusChangeAsync(z.ckObj, C.int(arg1), arg2.ckObj, arg3.ckObj)


    if hTask == nil {
        c <- NewTask()
        return
        }
    task := Task{hTask}
    c <- &task
    task.RunSynchronously()
    close(c)

}


// Cancels an ongoing GetStatusChange method call. This would be called from a
// separate thread in your application if GetStatusChange was called synchronously.
func (z *SCard) GetStatusChangeCancel() bool {

    v := C.CkSCard_GetStatusChangeCancel(z.ckObj)


    return v != 0
}


// Returns a list of currently available reader groups on the system. The reader
// groups are returned in readerGroups.
func (z *SCard) ListReaderGroups(arg1 *StringTable) bool {

    v := C.CkSCard_ListReaderGroups(z.ckObj, arg1.ckObj)


    return v != 0
}


// Returns a list of currently available readers on the system.
func (z *SCard) ListReaders(arg1 *StringTable) bool {

    v := C.CkSCard_ListReaders(z.ckObj, arg1.ckObj)


    return v != 0
}


// Reestablishes a connection to a reader that was previously connected to using
// Connect(). 
// 
// In a multi application environment it is possible for an application to reset
// the card in shared mode. When this occurs any other application trying to access
// certain commands will be returned the value SCARD_W_RESET_CARD. When this occurs
// Reconnect() must be called in order to acknowledge that the card was reset and
// allow it to change its state accordingly. 
// 
// The shareMode can be "shared", "exclusive", or "direct". The preferredProtocol can be "0" (valid
// only if the shareMode = "direct"), "T0", "T1", "raw", or "no_preference". (No
// preference is effectively T0 or T1.) The action is the desired action taken on the
// card/reader. It can be "leave", "reset", "unpower", or "eject". 
// 
// If successful, the state of this object instance is that it's connected to the
// reader.
//
func (z *SCard) Reconnect(arg1 string, arg2 string, arg3 string) bool {
    cstr1 := C.CString(arg1)
    cstr2 := C.CString(arg2)
    cstr3 := C.CString(arg3)

    v := C.CkSCard_Reconnect(z.ckObj, cstr1, cstr2, cstr3)

    C.free(unsafe.Pointer(cstr1))
    C.free(unsafe.Pointer(cstr2))
    C.free(unsafe.Pointer(cstr3))

    return v != 0
}


// Destroys a communication context to the PC/SC Resource Manager. This must be the
// last function called in a PC/SC application.
func (z *SCard) ReleaseContext() bool {

    v := C.CkSCard_ReleaseContext(z.ckObj)


    return v != 0
}


// Sends a command directly to the IFD Handler (reader driver) to be processed by
// the reader. 
// 
// This is useful for creating client side reader drivers for functions like PIN
// pads, biometrics, or other extensions to the normal smart card reader that are
// not normally handled by PC/SC. 
// 
// The command data is sent in bdSend. The response is written to bdRecv.
//
func (z *SCard) SendControl(arg1 uint, arg2 *BinData, arg3 *BinData) bool {

    v := C.CkSCard_SendControl(z.ckObj, C.ulong(arg1), arg2.ckObj, arg3.ckObj)


    return v != 0
}


// Sends a command directly to the IFD Handler (reader driver) to be processed by
// the reader. 
// 
// This is useful for creating client side reader drivers for functions like PIN
// pads, biometrics, or other extensions to the normal smart card reader that are
// not normally handled by PC/SC. 
// 
// The command data is provided as a hex string in sendData. The response is written to
// bdRecv.
//
func (z *SCard) SendControlHex(arg1 uint, arg2 string, arg3 *BinData) bool {
    cstr2 := C.CString(arg2)

    v := C.CkSCard_SendControlHex(z.ckObj, C.ulong(arg1), cstr2, arg3.ckObj)

    C.free(unsafe.Pointer(cstr2))

    return v != 0
}


// Sends an APDU to the smart card contained in the currently connected reader. The
// protocol can be "T0", "T1", or "raw". The APDU to be sent is contained in bdSend. The
// response from the card is contained in bdRecv. The maxRecvLen is the maximum response
// size (in bytes) willing to be accepted.
func (z *SCard) Transmit(arg1 string, arg2 *BinData, arg3 *BinData, arg4 int) bool {
    cstr1 := C.CString(arg1)

    v := C.CkSCard_Transmit(z.ckObj, cstr1, arg2.ckObj, arg3.ckObj, C.int(arg4))

    C.free(unsafe.Pointer(cstr1))

    return v != 0
}


// Sends an APDU to the smart card contained in the currently connected reader. The
// protocol can be "T0", "T1", or "raw". The APDU (in hexadecimal) to be sent is passed
// in apduHex. The response from the card is contained in bdRecv. The maxRecvLen is the
// maximum response size (in bytes) willing to be accepted.
func (z *SCard) TransmitHex(arg1 string, arg2 string, arg3 *BinData, arg4 int) bool {
    cstr1 := C.CString(arg1)
    cstr2 := C.CString(arg2)

    v := C.CkSCard_TransmitHex(z.ckObj, cstr1, cstr2, arg3.ckObj, C.int(arg4))

    C.free(unsafe.Pointer(cstr1))
    C.free(unsafe.Pointer(cstr2))

    return v != 0
}


